==> owncloud-10.0.7.tgz: owncloud/core/l10n/az.js <==
OC.L10N.register(
    "core",
    {
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "No temporary profile picture available, try again" : "Profaylın müvəqqəti şəklinə çatmaq mümkün olmadı, yenidən təkrarlayın.",
    "Couldn't send mail to following users: %s " : "Məktubu göstərilən istifadəçilərə göndərmək mümkün olmadı: %s",
    "Turned on maintenance mode" : "Xidməti rejimə keçilmişdir",
    "Turned off maintenance mode" : "Xidməti rejim söndürüldü",
    "Updated database" : "Yenilənmiş verilənlər bazası",
    "Checked database schema update" : "Baza sxeminin yenilənməsi yoxlanıldı",
    "Sunday" : "Bazar",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sun." : "Baz.",
    "Mon." : "Ber.",
    "Tue." : "Çax.",
    "Wed." : "Çər.",
    "Thu." : "Cax.",
    "Fri." : "Cüm.",
    "Sat." : "Şnb.",
    "January" : "Yanvar",
    "February" : "Fevral",
    "March" : "Mart",
    "April" : "Aprel",
    "May" : "May",
    "June" : "İyun",
    "July" : "İyul",
    "August" : "Avqust",
    "September" : "Sentyabr",
    "October" : "Oktyabr",
    "November" : "Noyabr.",
    "December" : "Dekabr",
    "Jan." : "Yan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "İyn.",
    "Jul." : "İyl.",
    "Aug." : "Avq.",
    "Sep." : "Sen.",
    "Oct." : "Okt.",
    "Nov." : "Noy.",
    "Dec." : "Dek.",
    "Settings" : "Quraşdırmalar",
    "Saving..." : "Saxlama...",
    "seconds ago" : "saniyələr öncə",
    "No" : "Xeyir",
    "Yes" : "Bəli",
    "Choose" : "Seç",
    "Ok" : "Oldu",
    "Cancel" : "Dayandır",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Error" : "Səhv",
    "Expiration" : "Vaxtın bitməsi",
    "Edit" : "Dəyişiklik et",
    "Remove" : "Sil",
    "Password" : "Şifrə",
    "Name" : "Ad",
    "Save" : "Saxla",
    "Email sent" : "Məktub göndərildi",
    "group" : "qrup",
    "Unshare" : "Paylaşımı durdur",
    "can share" : "yayımlaya bilərsiniz",
    "can edit" : "dəyişmək olar",
    "delete" : "sil",
    "Share" : "Yayımla",
    "Warning" : "Xəbərdarlıq",
    "Delete" : "Sil",
    "Rename" : "Adı dəyiş",
    "Add" : "Əlavə etmək",
    "Personal" : "Şəxsi",
    "Users" : "İstifadəçilər",
    "Admin" : "İnzibatçı",
    "Help" : "Kömək",
    "Cheers!" : "Şərəfə!",
    "Username" : "İstifadəçi adı",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Xüsusilə fayl sinxronizasiyası üçün desktop client-dən istifadə edilərsə, SQLite məsləhət görülmür.",
    "Search" : "Axtarış",
    "Log in" : "Giriş",
    "New password" : "Yeni şifrə",
    "You are accessing the server from an untrusted domain." : "Siz serverə inamsız domain-dən girməyə çalışırsız."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/core/l10n/az.js <==
OC.L10N.register(
    "core",
    {
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "No temporary profile picture available, try again" : "Profaylın müvəqqəti şəklinə çatmaq mümkün olmadı, yenidən təkrarlayın.",
    "Couldn't send mail to following users: %s " : "Məktubu göstərilən istifadəçilərə göndərmək mümkün olmadı: %s",
    "Turned on maintenance mode" : "Xidməti rejimə keçilmişdir",
    "Turned off maintenance mode" : "Xidməti rejim söndürüldü",
    "Updated database" : "Yenilənmiş verilənlər bazası",
    "Checked database schema update" : "Baza sxeminin yenilənməsi yoxlanıldı",
    "Sunday" : "Bazar",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sun." : "Baz.",
    "Mon." : "Ber.",
    "Tue." : "Çax.",
    "Wed." : "Çər.",
    "Thu." : "Cax.",
    "Fri." : "Cüm.",
    "Sat." : "Şnb.",
    "January" : "Yanvar",
    "February" : "Fevral",
    "March" : "Mart",
    "April" : "Aprel",
    "May" : "May",
    "June" : "İyun",
    "July" : "İyul",
    "August" : "Avqust",
    "September" : "Sentyabr",
    "October" : "Oktyabr",
    "November" : "Noyabr.",
    "December" : "Dekabr",
    "Jan." : "Yan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "İyn.",
    "Jul." : "İyl.",
    "Aug." : "Avq.",
    "Sep." : "Sen.",
    "Oct." : "Okt.",
    "Nov." : "Noy.",
    "Dec." : "Dek.",
    "Settings" : "Quraşdırmalar",
    "Saving..." : "Saxlama...",
    "seconds ago" : "saniyələr öncə",
    "No" : "Xeyir",
    "Yes" : "Bəli",
    "Choose" : "Seç",
    "Ok" : "Oldu",
    "Cancel" : "Dayandır",
    "Very weak password" : "Çox asan şifrə",
    "Weak password" : "Asan şifrə",
    "So-so password" : "Elə-belə şifrə",
    "Good password" : "Yaxşı şifrə",
    "Strong password" : "Çətin şifrə",
    "Error" : "Səhv",
    "Expiration" : "Vaxtın bitməsi",
    "Edit" : "Dəyişiklik et",
    "Remove" : "Sil",
    "Password" : "Şifrə",
    "Name" : "Ad",
    "Save" : "Saxla",
    "Email sent" : "Məktub göndərildi",
    "group" : "qrup",
    "Unshare" : "Paylaşımı durdur",
    "can share" : "yayımlaya bilərsiniz",
    "can edit" : "dəyişmək olar",
    "delete" : "sil",
    "Share" : "Yayımla",
    "Warning" : "Xəbərdarlıq",
    "Delete" : "Sil",
    "Rename" : "Adı dəyiş",
    "Add" : "Əlavə etmək",
    "Personal" : "Şəxsi",
    "Users" : "İstifadəçilər",
    "Admin" : "İnzibatçı",
    "Help" : "Kömək",
    "Cheers!" : "Şərəfə!",
    "Username" : "İstifadəçi adı",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Xüsusilə fayl sinxronizasiyası üçün desktop client-dən istifadə edilərsə, SQLite məsləhət görülmür.",
    "Search" : "Axtarış",
    "Log in" : "Giriş",
    "New password" : "Yeni şifrə",
    "You are accessing the server from an untrusted domain." : "Siz serverə inamsız domain-dən girməyə çalışırsız.",
    "Copy to clipboard" : "Buferə nüsxələ",
    "Imprint" : "İşarələmək"
},
"nplurals=2; plural=(n != 1);");
